==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModStructures.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.fabricmc.fabric.api.tag.convention.v2.ConventionalBiomeTags;
import net.minecraft.class_1959;
import net.minecraft.class_1972;
import net.minecraft.class_2893;
import net.minecraft.class_2902;
import net.minecraft.class_3195;
import net.minecraft.class_3785;
import net.minecraft.class_5321;
import net.minecraft.class_5434;
import net.minecraft.class_5843;
import net.minecraft.class_5847;
import net.minecraft.class_6121;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModStructures {

    public static final class_5321<class_3195> ABANDONED_ALTAR = getOrCreateRegistryKey("abandoned_altar");
    public static final class_5321<class_3195> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_3195> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_3195> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_3195> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_3195> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_3195> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_3195> context) {
        class_7871<class_1959> biomeLookup = context.method_46799(class_7924.field_41236);
        class_7871<class_3785> structurePoolLookup = context.method_46799(class_7924.field_41249);
        class_3195.class_7302. class_9821 forest = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_FOREST));
        forest.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 plains = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_PLAINS));
        plains.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 hill = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_HILL));
        hill.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 taiga = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_TAIGA));
        taiga.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 bambooForest = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_9440)));
        taiga.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 cherryForest = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_42720)));
        taiga.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);

        context.method_46838(
                ABANDONED_ALTAR,
                new class_5434(forest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.ABANDONED_ALTAR), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                ABANDONED_TORII,
                new class_5434(taiga.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.ABANDONED_TORII), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                MINI_BAR,
                new class_5434(plains.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.MINI_BAR), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                OUTER_SHRINE,
                new class_5434(forest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.OUTER_SHRINE), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                BAMBOO_FOREST_BBQ_STALL,
                new class_5434(bambooForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.BAMBOO_FOREST_BBQ_STALL), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                BAMBOO_FOREST_HUT,
                new class_5434(bambooForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.BAMBOO_FOREST_HUT), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                SAKURAZUKA,
                new class_5434(cherryForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.SAKURAZUKA), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
    }

    public static class_6880.class_6883<class_3195> register(class_7891<class_3195> registry, class_5321<class_3195> registryKey, class_3195 structure) {
        return registry.method_46838(registryKey, structure);
    }

    public static class_5321<class_3195> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41246, ReverieDreams.id(name));
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModStructures.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.fabricmc.fabric.api.tag.convention.v2.ConventionalBiomeTags;
import net.minecraft.class_1959;
import net.minecraft.class_1972;
import net.minecraft.class_2893;
import net.minecraft.class_2902;
import net.minecraft.class_3195;
import net.minecraft.class_3785;
import net.minecraft.class_5321;
import net.minecraft.class_5434;
import net.minecraft.class_5843;
import net.minecraft.class_5847;
import net.minecraft.class_6121;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModStructures {

    public static final class_5321<class_3195> ABANDONED_ALTAR = getOrCreateRegistryKey("abandoned_altar");
    public static final class_5321<class_3195> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_3195> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_3195> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_3195> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_3195> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_3195> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");
    public static final class_5321<class_3195> NETHER_HOT_SPRING = getOrCreateRegistryKey("nether_hot_spring");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_3195> context) {
        class_7871<class_1959> biomeLookup = context.method_46799(class_7924.field_41236);
        class_7871<class_3785> structurePoolLookup = context.method_46799(class_7924.field_41249);
        class_3195.class_7302. class_9821 forest = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_FOREST));
        forest.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 plains = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_PLAINS));
        plains.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 hill = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_HILL));
        hill.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 taiga = new class_3195.class_7302.class_9821(biomeLookup.method_46735(ConventionalBiomeTags.IS_TAIGA));
        taiga.method_61009(class_2893.class_2895.field_13173)
                .method_61010(class_5847.field_38431);
        class_3195.class_7302. class_9821 bambooForest = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_9440)));
        class_3195.class_7302. class_9821 cherryForest = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_42720)));
        class_3195.class_7302. class_9821 basaltDeltas = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_23859)));
        class_3195.class_7302. class_9821 netherWastes = new class_3195.class_7302.class_9821(class_6885.method_40246(biomeLookup.method_46747(class_1972.field_9461)));

        context.method_46838(
                ABANDONED_ALTAR,
                new class_5434(forest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.ABANDONED_ALTAR), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                ABANDONED_TORII,
                new class_5434(taiga.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.ABANDONED_TORII), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                MINI_BAR,
                new class_5434(plains.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.MINI_BAR), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                OUTER_SHRINE,
                new class_5434(forest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.OUTER_SHRINE), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                BAMBOO_FOREST_BBQ_STALL,
                new class_5434(bambooForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.BAMBOO_FOREST_BBQ_STALL), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                BAMBOO_FOREST_HUT,
                new class_5434(bambooForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.BAMBOO_FOREST_HUT), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                SAKURAZUKA,
                new class_5434(cherryForest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.SAKURAZUKA), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
        context.method_46838(
                NETHER_HOT_SPRING,
                new class_5434(forest.method_61008(), structurePoolLookup.method_46747(ModTemplatePools.NETHER_HOT_SPRING), 1, class_6121.method_35383(class_5843.method_33841(0)), false, class_2902.class_2903.field_13194)
        );
    }

    public static class_6880.class_6883<class_3195> register(class_7891<class_3195> registry, class_5321<class_3195> registryKey, class_3195 structure) {
        return registry.method_46838(registryKey, structure);
    }

    public static class_5321<class_3195> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41246, ReverieDreams.id(name));
    }
}
